/*
 * Gimbal
 * Copyright (C) 2024 moonleay
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package net.moonleay.gimbal.client.util.screen

import net.moonleay.gimbal.client.config.AnchorPoint

object ScreenUtil {

    fun getXForRender(x: Float, anchor: AnchorPoint, textWidth: Int): Float {
        return when (anchor) {
            AnchorPoint.TOP_LEFT -> x
            AnchorPoint.BOTTOM_LEFT -> x
            AnchorPoint.TOP_RIGHT -> x - textWidth
            AnchorPoint.BOTTOM_RIGHT -> x - textWidth
            AnchorPoint.CENTER -> x - textWidth / 2
        }
    }

    fun getYForRender(y: Float, anchor: AnchorPoint, textHeight: Int): Float {
        return when (anchor) {
            AnchorPoint.TOP_LEFT -> y
            AnchorPoint.TOP_RIGHT -> y
            AnchorPoint.BOTTOM_RIGHT -> y - textHeight
            AnchorPoint.BOTTOM_LEFT -> y - textHeight
            AnchorPoint.CENTER -> y - textHeight / 2
        }
    }

    fun getScaled(length: Int, real: Float): Double {
        val scale = length / 100.0
        return real / scale
    }

    fun getReal(length: Int, scaled: Double): Float {
        val scale = length / 100.0
        return (scaled * scale).toFloat()
    }

    fun isPositionOutOfBounds(x: Double, y: Double): Boolean {
        val tooBig = 100 < x || 100 < y
        val tooSmall = 0 > x || 0 > y
        return tooBig || tooSmall
    }

}
